==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/signalfx/SignalfxSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.signalfx;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Long;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface SignalfxSpecFluent<A extends SignalfxSpecFluent<A>> extends Fluent<A>{


    public String getAccessToken();
    public A withAccessToken(String accessToken);
    public Boolean hasAccessToken();
    public Long getDatapointInterval();
    public A withDatapointInterval(Long datapointInterval);
    public Boolean hasDatapointInterval();
    public A withNewDatapointInterval(String arg1);
    public A withNewDatapointInterval(long arg1);
    public String getIngestUrl();
    public A withIngestUrl(String ingestUrl);
    public Boolean hasIngestUrl();
    public A addToMetrics(int index,MetricConfig item);
    public A setToMetrics(int index,MetricConfig item);
    public A addToMetrics(MetricConfig... items);
    public A addAllToMetrics(Collection<MetricConfig> items);
    public A removeFromMetrics(MetricConfig... items);
    public A removeAllFromMetrics(Collection<MetricConfig> items);
    
/**
 * This method has been deprecated, please use method buildMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<MetricConfig> getMetrics();
    public List<MetricConfig> buildMetrics();
    public MetricConfig buildMetric(int index);
    public MetricConfig buildFirstMetric();
    public MetricConfig buildLastMetric();
    public MetricConfig buildMatchingMetric(io.fabric8.kubernetes.api.builder.Predicate<MetricConfigBuilder> predicate);
    public A withMetrics(List<MetricConfig> metrics);
    public A withMetrics(MetricConfig... metrics);
    public Boolean hasMetrics();
    public SignalfxSpecFluent.MetricsNested<A> addNewMetric();
    public SignalfxSpecFluent.MetricsNested<A> addNewMetricLike(MetricConfig item);
    public SignalfxSpecFluent.MetricsNested<A> setNewMetricLike(int index,MetricConfig item);
    public SignalfxSpecFluent.MetricsNested<A> editMetric(int index);
    public SignalfxSpecFluent.MetricsNested<A> editFirstMetric();
    public SignalfxSpecFluent.MetricsNested<A> editLastMetric();
    public SignalfxSpecFluent.MetricsNested<A> editMatchingMetric(io.fabric8.kubernetes.api.builder.Predicate<MetricConfigBuilder> predicate);

    public interface MetricsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MetricConfigFluent<SignalfxSpecFluent.MetricsNested<N>>{

        
    public N and();    public N endMetric();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/signalfx/SignalfxSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.signalfx;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.lang.Double;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface SignalfxSpecFluent<A extends SignalfxSpecFluent<A>> extends Fluent<A>{


    public String getAccessToken();
    public A withAccessToken(String accessToken);
    public Boolean hasAccessToken();
    public A withNewAccessToken(String arg1);
    public A withNewAccessToken(StringBuilder arg1);
    public A withNewAccessToken(StringBuffer arg1);
    public Integer getDatapointInterval();
    public A withDatapointInterval(Integer datapointInterval);
    public Boolean hasDatapointInterval();
    public Boolean isEnableMetrics();
    public A withEnableMetrics(Boolean enableMetrics);
    public Boolean hasEnableMetrics();
    public A withNewEnableMetrics(String arg1);
    public A withNewEnableMetrics(boolean arg1);
    public Boolean isEnableTracing();
    public A withEnableTracing(Boolean enableTracing);
    public Boolean hasEnableTracing();
    public A withNewEnableTracing(String arg1);
    public A withNewEnableTracing(boolean arg1);
    public String getIngestUrl();
    public A withIngestUrl(String ingestUrl);
    public Boolean hasIngestUrl();
    public A withNewIngestUrl(String arg1);
    public A withNewIngestUrl(StringBuilder arg1);
    public A withNewIngestUrl(StringBuffer arg1);
    public A addToMetrics(int index,MetricConfig item);
    public A setToMetrics(int index,MetricConfig item);
    public A addToMetrics(MetricConfig... items);
    public A addAllToMetrics(Collection<MetricConfig> items);
    public A removeFromMetrics(MetricConfig... items);
    public A removeAllFromMetrics(Collection<MetricConfig> items);
    public A removeMatchingFromMetrics(io.fabric8.kubernetes.api.builder.Predicate<MetricConfigBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<MetricConfig> getMetrics();
    public List<MetricConfig> buildMetrics();
    public MetricConfig buildMetric(int index);
    public MetricConfig buildFirstMetric();
    public MetricConfig buildLastMetric();
    public MetricConfig buildMatchingMetric(io.fabric8.kubernetes.api.builder.Predicate<MetricConfigBuilder> predicate);
    public Boolean hasMatchingMetric(io.fabric8.kubernetes.api.builder.Predicate<MetricConfigBuilder> predicate);
    public A withMetrics(List<MetricConfig> metrics);
    public A withMetrics(MetricConfig... metrics);
    public Boolean hasMetrics();
    public SignalfxSpecFluent.MetricsNested<A> addNewMetric();
    public SignalfxSpecFluent.MetricsNested<A> addNewMetricLike(MetricConfig item);
    public SignalfxSpecFluent.MetricsNested<A> setNewMetricLike(int index,MetricConfig item);
    public SignalfxSpecFluent.MetricsNested<A> editMetric(int index);
    public SignalfxSpecFluent.MetricsNested<A> editFirstMetric();
    public SignalfxSpecFluent.MetricsNested<A> editLastMetric();
    public SignalfxSpecFluent.MetricsNested<A> editMatchingMetric(io.fabric8.kubernetes.api.builder.Predicate<MetricConfigBuilder> predicate);
    public Integer getTracingBufferSize();
    public A withTracingBufferSize(Integer tracingBufferSize);
    public Boolean hasTracingBufferSize();
    public Double getTracingSampleProbability();
    public A withTracingSampleProbability(Double tracingSampleProbability);
    public Boolean hasTracingSampleProbability();

    public interface MetricsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MetricConfigFluent<SignalfxSpecFluent.MetricsNested<N>>{

        
    public N and();    public N endMetric();
}


}
